Description Usage Arguments Value
This function creates a websocket connection to a remote instance using the Chrome Debugging Protocol.
1 2 3 4 5 6 7 8 |
host |
Character scalar, the host name of the application. |
port |
The remote debugging port (a numeric or a character scalar). |
secure |
A logical indicating whether a secure protocol shall be used. |
ws_url |
Character scalar, the websocket URL. If provided, |
local |
Logical scalar, indicating whether the local version of the
protocol (embedded in |
callback |
Function with one argument, executed when the R session is connected to Chrome. The connection object is passed to this function. |
The returned value depends on the value of the callback argument.
When callback is a function, the returned value is a connection object
of class CDPSession. When callback is NULL the returned value is
a promise which becomes fulfilled once R is connected to the remote
instance. Once fulfilled, the value of this promise is the connection
object of class CDPSession.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.